@@ -440,7 +440,7 @@ require('loadDepartment.php');
             </li>
 				<input type='hidden' id='deptMode' name='deptMode' value='<?php echo $deptMode ?>'>
 				<input type='hidden' id='deptName' name='deptName' value='<?php echo $deptName ?>'>
-				<input type='hidden' id='guid' name='guid' value=''>
+				<input type='hidden' id='guid' name='guid' value='<?php echo $deptguid ?>'>
 			</form>
 			<!-- fourth tab -->
 			
