@@ -105,12 +105,13 @@ $(document).ready(function() {
 	$("#btn_delete").click(function() {
 		//console.log ('del')
 		var selected = $('#departments tr.selected').attr('id');
+		var timestamp = Math.floor(Date.now() / 1000); 
 		if (typeof selected != "undefined" && selected.length > 3)
 		var n = noty({
         type: 'warning', layout: 'center', text: 'Delete Department: <b>' + selectedName + '</b> ?', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1, 
 		buttons     : [
             {addClass: 'btn btn-primary', text: 'OK', onClick: function ($noty) {
-				$.ajax({ url : 'departmentActions.php?mode=deleteDept&deptName=' + encodeURIComponent(selectedName) });
+				$.ajax({ url : 'departmentActions.php?mode=deleteDept&deptName=' + encodeURIComponent(selectedName) + '&deptguid=' + encodeURIComponent(selected) + '&timestamp=' + timestamp });
 					oTable.fnDeleteRow( oTable.$('#' + selected)[0] );
                     $noty.close(); 
 				}
@@ -135,7 +136,7 @@ $(document).ready(function() {
 		
         $('#element_to_pop_up').bPopup({
 			escClose: false, modalClose: false,
-            loadUrl: 'departmentForm.php?deptMode=editDept&deptName=' + encodeURIComponent(selectedName),
+            loadUrl: 'departmentForm.php?deptMode=editDept&deptName=' + encodeURIComponent(selectedName) + '&deptguid=' + guid,
 			loadCallback: function(){ 	    
 				originalFormData = $('#new_dept').serialize();
 				
@@ -178,6 +179,8 @@ $(document).ready(function() {
 	$("body").on('click', '#save', function(){
 	var saveDept = $('#cn').val();
 	var saveTele = $('#telephonenumber').val();
+	var timestamp = Math.floor(Date.now() / 1000); 
+	
 	if (saveDept.length < 1 || saveTele.length < 1) {
 		var n = noty({ type: 'error', layout: 'center', text: 'Department Name and Telephone Number must be set<br/><br/><i>click to close</i>', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 })
 		return false;
@@ -193,7 +196,7 @@ $(document).ready(function() {
 					type: "POST", 
 					cache: false,
 					data: $('#new_dept').serializeArray(),
-					url: "departmentActions.php?mode=saveDept", 	
+					url: "departmentActions.php?mode=saveDept&timestamp=" + timestamp, 	
 				success: function(data) {
 					res = data.split(":");
 					var deptMode = res[0];
@@ -205,13 +208,12 @@ $(document).ready(function() {
 					
 					
 				// Update Voicemail Monitors
-				if (monitorvalues.length > 0) {
-					
+				if (typeof monitorvalues != "undefined" && monitorvalues.length > 0) {
 					$.ajax({
 						type: "POST", 
 						cache: false,
 						data: { monitorvaluesArray: monitorvalues },
-						url: "departmentActions.php?mode=vmMonitor&deptGuid=" + encodeURIComponent(guid), 	
+						url: "departmentActions.php?mode=vmMonitor&deptGuid=" + encodeURIComponent(guid) + '&timestamp=' + timestamp , 	
 						success: function(data) {
 							//console.log (data)
 						}
