@@ -2,10 +2,12 @@
 session_start();
 require('../assets/inc/ldapConnect.php');
 $mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
+$timestamp = (isset($_REQUEST['timestamp']) && strlen($_REQUEST['timestamp']) >=1 ) ? $_REQUEST['timestamp'] : time();
 
 
 if (isset($_REQUEST['loaded'])) {
 	$_SESSION['loaded'] =1;
+	audit ($timestamp, "[Contacts] [Warning]","Contacts warning accepted");
 	exit();
 }
 
@@ -16,6 +18,7 @@ if ($mode === 'fileCheck') {
 	$file = ($company === '') ? "contacts.out.txt" : "contacts.out.$company.txt";
 	$result = (file_exists("/SpliceCom/ftp/$file")) ? '1' : '0';
 	echo $result;
+	audit ($timestamp, "[Contacts] [FileCheck]","Contacts file checked");
 }
 
 //upload file
