@@ -58,6 +58,7 @@ $(document).ready(function() {
 	// delete selected //
 	$("#btn_delete").click(function() {
 		if (typeof selectedGuid == "undefined" || selectedGuid.length < 1 ) return false;
+		var timestamp = Math.floor(Date.now() / 1000); 
 			
 		var typeofphone = $('#endpoints tr.selected').children(':eq(3)').text();
 
@@ -70,7 +71,7 @@ $(document).ready(function() {
         type: 'warning', layout: 'center', text: 'Delete Selected Phone : <b>' + decodeURIComponent(selectedName) + '</b> ?', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1, 
 		buttons     : [
             {addClass: 'btn btn-primary', text: 'Yes', onClick: function ($noty) {
-				$.ajax({ url : 'actions.php?actionMode=delete&selectedGuid=' + selectedGuid });
+				$.ajax({ url : 'actions.php?actionMode=delete&selectedGuid=' + selectedGuid + '&timestamp=' + timestamp});
 					oTable.fnDeleteRow( oTable.$('#' + selectedGuid)[0] );
 					selectedGuid = selectedName = '';
                     $noty.close(); 
@@ -130,6 +131,7 @@ $(document).ready(function() {
 	$("body").on('click', '#addEndPoint', function(){
 	var newEndPoint = ($('#selectphone').val() === '2') ? '00-07-D9-' + $('#pcsMac').val() : $('#sipName').val();
 	var assignUserName = ($('#assignUserOn').is(':checked')) ? $('#assignUser option:selected').text() : '';
+	var timestamp = Math.floor(Date.now() / 1000); 
 	 
 	 if ($('#selectphone').val() === '3' && $('#sipType').val() === '1') {
 		if ($('#sipMACAddress').val().length < 12) {
@@ -152,6 +154,7 @@ $(document).ready(function() {
             {addClass: 'btn btn-primary', text: 'OK', onClick: function ($noty) {
 				data = $('#popup').serializeArray(),
 				data.push({name: 'assignUserName', value: assignUserName});
+				data.push({name: 'timestamp', value: timestamp});
 
 				$.ajax({
 					type: "POST", 
@@ -191,6 +194,8 @@ $(document).ready(function() {
 	// save Edit EndPoint
 	$("body").on('click', '#editEndpoint', function(){
 	 var editEndPoint = $('#phoneName').val();
+	 var timestamp = Math.floor(Date.now() / 1000); 
+	 
 		var n = noty({
         type: 'information', layout: 'center', text: 'Save Phone: <b>' + editEndPoint + '</b> ?', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1, 
 		buttons     : [
@@ -199,7 +204,7 @@ $(document).ready(function() {
 					type: "POST", 
 					cache: false,
 					data: $('#popup').serializeArray(),	
-					url: "actions.php?actionMode=editEndpoint", 	
+					url: "actions.php?actionMode=editEndpoint&timestamp=" + timestamp, 	
 				success: function(data) {
 					console.log(data)
 					res = data.split(":");
@@ -543,6 +548,7 @@ $(document).ready(function() {
 	
 	// restart SoftPBX
 	$("body").on('click', '#restartAdmin', function(){
+		var timestamp = Math.floor(Date.now() / 1000); 
 		var n = noty({
         type: 'error', layout: 'center', text: 'Restarting the SoftPBX will disconnect live calls and log out phones<br>The system will be unavailable for a few minutes whilst this happens<br><br>Do you want to continue ?', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1, 
 		buttons     : [
@@ -550,7 +556,7 @@ $(document).ready(function() {
 				$.ajax({
 					type: "POST", 
 					cache: false,
-					url: "actions.php?actionMode=restartModule", 	
+					url: "actions.php?actionMode=restartModule&timestamp=" + timestamp, 	
 				success: function(data) {
 					$('#restartAdmin').hide();
 					console.log(data)
@@ -572,6 +578,18 @@ $(document).ready(function() {
         });	
 	});
 	
+	$("body").on('click', '.tooltip', function() {
+		extnlist = ( $(this).data('list') )
+		console.log  (extnlist)
+		$('#extensions_pop_up').bPopup({
+			escClose: true, modalClose: true,
+			onOpen: function() { 	    
+				$('#extensions').html(extnlist)
+			}
+		}); 
+	})
+		
+	
 });
 
 	// save and/or edit return values to update table
