@@ -1,23 +1,8 @@
 	$(document).ready(function(){
 		$('#wizard').smartWizard({transitionEffect:'slideleft',keyNavigation:false,onShowStep:getStepNum,onLeaveStep:leaveAStepCallback,onFinish:onFinishCallback,enableFinishButton:false});
 				
-		$(function() {
-		sipName = $('#sip_name').val();
-		var response = '';
-		$.ajax({ type: "GET",   
-         url: "../assets/inc/names.php?sip=" + encodeURIComponent(sipName),   
-         async: true,
-         success : function(text) {
-             response = text;
-			 if (response.toLowerCase().indexOf("error") >= 0) {
-				sipNameError = 1
-			 } else {
-				sipNameError = 0
-			 }
-         }
-		});
-		});
-
+		sipnameCheck();
+		
 		wanIP = '';
 		wanIPURL = 'http://jsonip.com?callback=?';
 		$.ajax({
@@ -29,6 +14,70 @@
 			}
 		});
 		
+		// hide Teams entries by default
+		$('.teamstrunk').hide()
+		var dialplanwarning = 0
+				
+		$('#module_type').on('change', function() {
+			module_type  = $(this).val()
+			
+			if ( module_type == 4 ){
+				$('#step1desc, #step2desc, #step3desc, #step5desc, #step5small, #step1title, #step2title, #step3title, #step5title').text('Teams')
+				
+				$('#sip_name').val('Teams Trunk');
+				$('#sip_desc').val('Teams Internal Trunk');
+				$('#sip_dnsip').val('').attr('placeholder','sbc.splicecom.com');
+				$('.siptrunk').hide();
+				$('.teamstrunk').show();
+				
+				if ( $('#sip_encryption').val() == 1 ) {
+					$('#sip_source').val('5062')
+				} else {
+					$('#sip_source').val('5060')
+				}
+				
+				
+			} else {
+				$('#step1desc, #step2desc, #step3desc, #step5desc, #step5small, #step1title, #step2title, #step3title, #step5title').text('SIP')
+				$('#sip_name').val('TalkTalkSIP');
+				$('#sip_desc').val('TalkTalk SIP Trunk');
+				$('#sip_dnsip').val('91.146.112.10').attr('placeholder','');
+				$('.siptrunk').show();
+				$('.teamstrunk').hide();
+				
+				if ( $('#sip_encryption').val() == 1 ) {
+					$('#sip_source').val('5061')
+				} else {
+					$('#sip_source').val('5060')
+				}
+			}
+			
+			sipnameCheck()
+			trimname = $('#sip_name').val().replace(' ','')
+			$('#sip_trunkgrp').val(trimname + 'TrkGrp')
+			$('#sip_lcrplan').val(trimname + 'LCRPlan')
+		})
+		
+		$('#sip_encryption').on('change', function() {
+			encryption_type = $(this).val()
+			if ( encryption_type == 1 ) {
+				$('#sip_source').val('5062');
+				$('#sip_nat_port').val('5061');
+				$('#sip_rec_port').val('5061');
+				
+				if ( $('#module_type').val() == 4 ) {
+					$('#sip_source').val('5062')
+				} else {
+					$('#sip_source').val('5061')
+				}
+				
+			} else {
+				$('#sip_source, #sip_nat_port,#sip_rec_port').val('5060');
+			}
+		})
+			
+			
+		
 		
 		function alert(type, layout, text) {
 			var n = noty({
@@ -38,6 +87,7 @@
 		
 		function getStepNum() {
 			stepNum = $('#wizard').smartWizard('currentStep');
+			//console.log (stepNum)
 			
 			if (stepNum > 1) {
 				$('.buttonSkip').remove();	
@@ -59,9 +109,10 @@
 				summaryNATMode = $('#sip_nat_mode').val();
 				summaryNATPort = $('#sip_nat_port').val();
 				summaryTrunkGroup = $('#sip_trunkgrp').val();
-				summaryDDIPlan = $('#sip_ddiplan option:selected').text();
+				//summaryDDIPlan = $('#sip_ddiplan option:selected').text();
 				summaryLCRPlan = $('#sip_lcrplan').val();
-				
+				summaryEncryption = ( $('#sip_encryption').val() == 0) ? 'Disabled' : 'Enabled'
+								
 				if ($('#dnssrv').length && $('#sip_regcontact').length && $('#sip_regdomain').length) {
 					summaryDNSSRV = $('#dnssrv').is(':checked') ? 'Enabled' : 'Disabled';
 					summaryRegContact = ($('#sip_regcontact').val().length >0) ? $('#sip_regcontact').val() : 'Not Set';
@@ -119,8 +170,9 @@
 				$('#summaryNATMode').html(summaryNATMode);
 				$('#summaryNATPort').html(summaryNATPort);
 				$('#summaryTrunkGroup').html(summaryTrunkGroup);
-				$('#summaryDDIPlan').html(summaryDDIPlan);
+				//$('#summaryDDIPlan').html(summaryDDIPlan);
 				$('#summaryLCRPlan').html(summaryLCRPlan);
+				$('#summaryEncryption').html(summaryEncryption);
 				
 				if ($('#dnssrv').length && $('#sip_regcontact').length && $('#sip_regdomain').length) {
 					$('#summaryDNSSRV').html(summaryDNSSRV);
@@ -128,6 +180,24 @@
 					$('#summaryRegDomain').html(summaryRegDomain);
 				}
 				
+			}
+			
+			if ( stepNum == '5') {
+				summaryTeamsDDIPlan = $('#teams_dialplan option:selected').text();
+				summaryTeamsLCRNumberMatch = $('#teams_lcrplan_numbermatch').val();
+				summaryTeamsLCRTranslateTo = $('#teams_lcrplan_translateto').val();
+				$('#summaryTeamsDDIPlan').html(summaryTeamsDDIPlan);
+				
+				if (summaryTeamsLCRNumberMatch.length >=1 && summaryTeamsLCRTranslateTo.length >=1) {
+					$('#summaryTeamsLCRNumberMatch').html(summaryTeamsLCRNumberMatch);
+					$('#summaryTeamsLCRTranslateTo').html(summaryTeamsLCRTranslateTo);
+					$('.teamslcrplan').show();
+				} else {
+					$('.teamslcrplan').hide();
+				}
+				
+				
+				
 			}
 		}
 		
@@ -328,6 +398,7 @@
 	function validateStep1(){
 		var isValid = true; 
 		var trunkName = $('#sip_name').val();
+		var dnsip = $('#sip_dnsip').val();
 		var sipcaps = $('#sip_caps').val();
 		var presenationNumber = $('#sip_pres').val();
 		
@@ -338,7 +409,7 @@
 			sipPassword = $('#sip_password').val();
 			
 			if (!sipDNSIPUser && sipDNSIPUser.length <= 0) {			
-				$('#wizard').smartWizard('showMessage','SIP Registrar DNS/IP Address must be set');
+				$('#wizard').smartWizard('showMessage','Registrar DNS/IP Address must be set');
 				$("#sip_dnsip_user").css({ 'border': '2pt solid #D00', 'color': '#D00'});
 				isValid = false; return false;
 			} else {
@@ -347,7 +418,7 @@
 			}
 			
 			if (!sipUsername && sipUsername.length <= 0) {			
-				$('#wizard').smartWizard('showMessage','SIP Username must be set');
+				$('#wizard').smartWizard('showMessage','Username must be set');
 				$("#sip_username").css({ 'border': '2pt solid #D00', 'color': '#D00'});
 				isValid = false; return false;
 			} else {
@@ -356,7 +427,7 @@
 			}
 			
 			if (!sipPassword && sipPassword.length <= 0) {			
-				$('#wizard').smartWizard('showMessage','SIP Password must be set');
+				$('#wizard').smartWizard('showMessage','Password must be set');
 				$("#sip_password").css({ 'border': '2pt solid #D00', 'color': '#D00'});
 				isValid = false; return false;
 			} else {
@@ -373,7 +444,7 @@
 		}
 		
 		if (!trunkName && trunkName.length <= 0) {
-			$('#wizard').smartWizard('showMessage','SIP Trunk Name must be set.');
+			$('#wizard').smartWizard('showMessage','Trunk Name must be set.');
 			$("#sip_name").css({ 'border': '2pt solid #D00', 'color': '#D00'});
 			isValid = false;    
 			return false;
@@ -382,8 +453,18 @@
 			$("#sip_name").css({ 'border': '1pt solid #DFDFDF', 'color': '#222'});
 		}
 		
+		if (!dnsip && dnsip.length <= 0) {
+			$('#wizard').smartWizard('showMessage','DNS / IP Address must be set.');
+			$("#sip_dnsip").css({ 'border': '2pt solid #D00', 'color': '#D00'});
+			isValid = false;    
+			return false;
+		} else {
+			$('#wizard').smartWizard('hideMessage');
+			$("#sip_dnsip").css({ 'border': '1pt solid #DFDFDF', 'color': '#222'});
+		}
+		
 		if (!sipcaps && sipcaps.length <= 0 || !$.isNumeric(sipcaps)) {
-			$('#wizard').smartWizard('showMessage','SIP Capacity Name must be set (numeric value)');
+			$('#wizard').smartWizard('showMessage','Capacity Name must be set (numeric value)');
 			$("#sip_caps").css({ 'border': '2pt solid #D00', 'color': '#D00'});
 			isValid = false;    
 			return false;
@@ -446,6 +527,7 @@
 					data: $('#SIPTrunk').serializeArray(),
 					url: "saveSIP.php", 	
 					success: function(data) {
+						console.log (data)
 						n.close();
 						$('#newTrunk').html(summaryTrunk);
 						$('#newTrunkGroup').html(summaryTrunkGroup);
@@ -453,10 +535,20 @@
 						$('#colFull').replaceWith($('#sipDone').html());
 						$(".buttonFinish").addClass('buttonDisabled');
 						$(".buttonPrevious").addClass('buttonDisabled');
-						$('.actionBar').prepend('<a href="#" class="buttonPortal">Portal</a>');
+						if ( $('#referrer').val().indexOf('welcome') === 0 ) {
+							$('.actionBar').prepend('<a href="#" data-loc="admin" class="buttonPortal">Portal</a>');
+						} else {
+							$('.actionBar').prepend('<a href="#" data-loc="manager" class="buttonPortal">Manager</a>');
+						}
 						$('.buttonPortal').click(function() {
-							$("body").fadeOut(500,function(){
-								$(location).attr('href','/manager/admin');
+							loc = ( $(this).data('loc') )
+							$("body").fadeOut(500,function() {
+								if ( loc == 'admin' ) {
+									$(location).attr('href','/manager/admin');
+								} else {
+									$(location).attr('href','/manager');
+								}
+									
 							});
 						});
 						return false;
@@ -482,12 +574,20 @@
 		console.log ('DialPlan = ' + sip_update_dialplan)
 		
 		if (sip_update_dialplan === 1) {
+			
+			if ( $('#module_type').val() == '4' && dialplanwarning == 0 ) {
+				alert('warning', 'center', 'Are you Sure ?.<br/>');
+				$('#wizard').smartWizard('showMessage','Warning - Incorrect settings can kill routing');
+				dialplanwarning = 1
+			}
+			
 			$('#sip_dialplan, #sip_dialplan_blank, #sip_dialplan_additional, #sip_dialplan_code').prop('disabled', false);
 			$('#summaryDialPlan').html('Yes');
 		} else {
 			$('#sip_dialplan, #sip_dialplan_blank, #sip_dialplan_additional, #sip_dialplan_code').prop('disabled', true);			
 			$('#sip_dialplan_blank, #sip_dialplan_additional').prop('checked', false);
 			$('#summaryDialPlan').html('No');
+			$('#wizard').smartWizard('hideMessage');
 		}
 	});
 	
@@ -513,15 +613,6 @@
 	});
 	
 	
-	//$('#sip_dialplan_additional').change(function(e) {	    
-	//	sip_dialplan_additional = $('#sip_dialplan_additional').is(':checked') ? 1 : 0;
-	//	if (sip_dialplan_additional === 1) {
-	//		$('#sip_dialplan_code').prop('disabled', false);
-	//	} else {
-	//		$('#sip_dialplan_code').prop('disabled', true);
-	//	}
-	//});
- 
  	$("#sip_noemerg_lcrplan").click( function(){
 		if( $(this).is(':checked') ) alert('error', 'center', '<b>Emergency Services</b><br/>Removing these entries may result in you not being able to call emergency services.<br/>');
 	});	
@@ -542,6 +633,9 @@
 	  
 	  
 	  function showSkip() {
+		console.log ( $('#referrer').val().indexOf('welcome') )
+	  if ( $('#referrer').val().indexOf('welcome') === -1 ) 	return
+		  
 	  if ($(".actionBar").find(".buttonSkip").length < 1) { 
 		$('.actionBar').append('<a href="#" class="buttonSkip">Skip Wizard</a>');
 		$('.buttonSkip').click(function() {
@@ -561,5 +655,24 @@
 		});
 	  }
 	  }
+	  
+	 function sipnameCheck() {
+		sipName = $('#sip_name').val();
+		//console.log ('SIP Name : ' + sipName)
+		var response = '';
+		$.ajax({ type: "GET",   
+         url: "../assets/inc/names.php?sip=" + encodeURIComponent(sipName),   
+         async: true,
+         success : function(text) {
+			 //console.log ('SIP Name Check: ' + text)
+             response = text;
+			 if (response.toLowerCase().indexOf("error") >= 0) {
+				sipNameError = 1
+			 } else {
+				sipNameError = 0
+			 }
+         }
+		});
+		};
 	
 });
\ No newline at end of file
