@@ -97,14 +97,17 @@ require('loadUser.php');
 				
 					<div class='field wide'>
 						<label for="initialphonemodule">Initial Phone</label>
-						<select id='initialphonemodule' name='initialphonemodule'>
+						<select id='initialphonemodule' name='initialphonemodule' <?php if ($usertype == 1) echo 'disabled' ?>>
 							<option value='clear'></option>
 							<?php
-								$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)(moduletype=22)))");
+								$initial_module_guid = '';
+								$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=13)(moduletype=14)(moduletype=17)(moduletype=18)(moduletype=19)(moduletype=22)))");
 								$info = ldap_get_entries($ds, $sr);
 								for ($m=0; $m<$info['count']; $m++) {				
 								$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
-								if ($initial_phone_module == $cn) {
+								if ($usertype == 1) {
+									$selected = ""; 
+								} elseif ($initial_phone_module == $cn) {
 									$selected = "selected"; $initial_module_guid = $guid;
 								} else {
 									$selected = "";	
@@ -114,7 +117,7 @@ require('loadUser.php');
 							?>
 						</select>
 						
-						<select id='initialphone' name='initialphone'>
+						<select id='initialphone' name='initialphone' <?php if ($usertype == 1) echo 'disabled' ?>>
 							<option></option>
 							<?php
 							$multipleDevices = array('W5', 'W6', 'T53', 'T54', 'T57', 'VP59');
@@ -125,14 +128,13 @@ require('loadUser.php');
 									$setinitialphones[] = $info[$m]['initialphone'][0];
 								}
 								$tmp = array_count_values($setinitialphones);
-								var_dump($tmp);
 								
-								$sr = @ldap_list($ds,"guid=$initial_module_guid,cn=modules","(objectclass=phone)", array('cn','guid'));
+								$sr = @ldap_list($ds,"guid=$initial_module_guid,cn=modules","(&(objectclass=phone)(typeofphone<=3))", array('cn','guid'));
 								$info = @ldap_get_entries($ds, $sr);  $modules ='';
 								
 								for ($m=0; $m<$info['count']; $m++) {				
 									$guid = $info[$m]['guid'][0]; 
-									
+							
 									$sr2 = ldap_read($ds,"cn=1,guid=$guid","objectclass=*",array('guid','pnpmodel')); 
 									$info2 = ldap_get_entries($ds,$sr2);	
 									$pnpmodel = (isset($info2[0]['pnpmodel'][0])) ? $info2[0]['pnpmodel'][0] : '';
@@ -198,6 +200,12 @@ require('loadUser.php');
 						</select>
 						<span class='information'>SELECT COMPANY</span>
 					</div>
+					
+					<div class='field'>
+						<label>Call Select</label>
+						<div class='checkbox'><label for="callselect"><div class="switch"><input type="checkbox" name='callselect' id='callselect' value="1" <?php if ($callselect == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
+						<span class='information'>CALL SELECT</span>
+					</div>
 				<?php 
 				} 
 				?>
@@ -213,6 +221,12 @@ require('loadUser.php');
 				<!-- #left -->
 				<div class="colLeft">
 				
+				<div class='field'>
+					<label>Enable Voicemail</label>
+					<div class='checkbox'><label for="voicemailenabled"><div class="switch"><input type="checkbox" name='voicemailenabled' id='voicemailenabled' value="1" <?php if ($voicemailenabled == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
+					<span class='information'>ENABLE VOICEMAIL</span>
+				</div>
+				
 				<div class='field'>
 					<label for="currenthome">Voicemail Home</label>
 					<select id='currenthome' name='currenthome' value='<?php echo $currenthome ?>' >
@@ -247,11 +261,17 @@ require('loadUser.php');
 					<input type='password' id='loginaccesscode' name='loginaccesscode' value='<?php echo $loginaccesscode ?>' >
 					<span class='information'>USERS LOGIN ACCESS CODE</span>
 				</div>
+				
 				</div> 
 				<!-- #left -->
 				
 				<!-- #right -->
 				<div class="colRight">
+				<div class='field'>
+					<label for="dectline">Preferred DECT Line</label>
+					<input type='text' id='dectline' name='dectline' value='<?php echo $dectline ?>' >
+					<span class='information'>PREFERRED DECT LINE</span>
+				</div>
 				<div class='field'>
 					<label for="hometelephonenumber">Home Phone Number</label>
 					<input type='text' id='hometelephonenumber' name='hometelephonenumber' value='<?php echo $hometelephonenumber ?>' >
@@ -306,14 +326,14 @@ require('loadUser.php');
 					
 						
 					// plain number / name match
-					if (preg_match("/^[a-zA-Z0-9]*$/", $followmeto)) {
+					if (preg_match("/^[a-zA-Z0-9 ]*$/", $followmeto)) {
 						if ($userCount === '1') {
 							$selectUser = 'selected';
 						} elseif ($departmentCount === '1') {
 							$selectDepartment = 'selected';
-						} elseif (strlen($hometelephonenumber) >= '1' && $followme > 0 && $followmeto == $hometelephonenumber) {
+						} elseif (strlen($hometelephonenumber) >= '1' && $followme > 0 && str_replace(' ','',$followmeto) == str_replace(' ','',$hometelephonenumber) ) {
 							$selectHome = 'selected';
-						} elseif (strlen($mobiletelephonenumber) >= '1' && $followme > 0 && $followmeto == $mobiletelephonenumber) {
+						} elseif (strlen($mobiletelephonenumber) >= '1' && $followme > 0 && str_replace(' ','',$followmeto) == str_replace(' ','',$mobiletelephonenumber) ) {
 							$selectMobile = 'selected';
 						} elseif ($followme === '0') {
 							$selectNone = 'disabled';
@@ -408,14 +428,14 @@ require('loadUser.php');
 						}
 						
 						// plain number / name match
-						if (preg_match("/^[a-zA-Z0-9]*$/", $forwardonbusyto)) {
+						if (preg_match("/^[a-zA-Z0-9 ]*$/", $forwardonbusyto)) {
 							if ($userCount === '1') {
 								$selectUser = 'selected';
 							} elseif ($departmentCount === '1') {
 								$selectDepartment = 'selected';
-							} elseif (strlen($hometelephonenumber) >= '1' && $forwardonbusy > 0  && $forwardonbusyto == $hometelephonenumber) {
+							} elseif (strlen($hometelephonenumber) >= '1' && $forwardonbusy > 0  && str_replace(' ','',$forwardonbusyto) == str_replace(' ','',$hometelephonenumber) ) {
 								$selectHome = 'selected';
-							} elseif (strlen($mobiletelephonenumber) >= '1' && $forwardonbusy > 0 && $forwardonbusyto == $mobiletelephonenumber) {
+							} elseif (strlen($mobiletelephonenumber) >= '1' && $forwardonbusy > 0 && str_replace(' ','',$forwardonbusyto) == str_replace(' ','',$mobiletelephonenumber) ) {
 								$selectMobile = 'selected';
 							} elseif ($forwardonbusy === '0') {
 								$selectNone = 'disabled';
@@ -502,14 +522,14 @@ require('loadUser.php');
 						
 						}
 						// plain number / name match
-						if (preg_match("/^[a-zA-Z0-9]*$/", $forwardonnoanswerto)) {
+						if (preg_match("/^[a-zA-Z0-9 ]*$/", $forwardonnoanswerto)) {
 							if ($userCount === '1') {
 								$selectUser = 'selected';
 							} elseif ($departmentCount === '1') {
 								$selectDepartment = 'selected';
-							} elseif (strlen($hometelephonenumber) >= '1' && $forwardonnoanswer > 0  && $forwardonnoanswerto == $hometelephonenumber) {
+							} elseif (strlen($hometelephonenumber) >= '1' && $forwardonnoanswer > 0  && str_replace(' ','',$forwardonnoanswerto) == str_replace(' ','',$hometelephonenumber) ) {
 								$selectHome = 'selected';
-							} elseif (strlen($mobiletelephonenumber) >= '1' && $forwardonnoanswer > 0 && $forwardonnoanswerto == $mobiletelephonenumber) {
+							} elseif (strlen($mobiletelephonenumber) >= '1' && $forwardonnoanswer > 0 && str_replace(' ','',$forwardonnoanswerto) == str_replace(' ','',$mobiletelephonenumber) ) {
 								$selectMobile = 'selected';
 							} elseif ($forwardonnoanswer === '0') {
 								$selectNone = 'disabled';
@@ -578,8 +598,11 @@ require('loadUser.php');
 						
 						<span class='information'>SET FORWARD ON NO ANSWER MODE AND DESTINATION</span>
 					</div>
-					
-					<br><div class='field'>
+				
+				</div> 				
+				
+				<div class="colLeft">
+					<div class='field'>
 					<label for="callwaiting">Call Waiting</label>
 						<select id='callwaiting' name='callwaiting'>
 							<option value='0' <?php if ($callwaiting =='0') echo 'selected' ?> >Disable</option>
@@ -589,8 +612,18 @@ require('loadUser.php');
 						<select>
 						<span class='information'>SET CALL WAITING</span>
 					</div>	
+				</div>	
+				
+				<div class="colRight">
+					<div class='field'>
+						<label>Do Not Disturb</label>
+						<div class='checkbox'><label for="donotdisturb"><div class="switch"><input type="checkbox" name='donotdisturb' id='donotdisturb' value="1" <?php if ($donotdisturb == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
+						<span class='information'>ENABLE DO NOT DISTURB</span>
+					</div>	
+				</div>	
+
+				
 				
-				</div> 
 				<!-- #right -->
 				
             </li>
@@ -692,6 +725,7 @@ require('loadUser.php');
 				
 				<input type='hidden' id='userMode' name='userMode' value='<?php echo $userMode ?>'>
 				<input type='hidden' id='userName' name='userName' value='<?php echo $userName ?>'>
+				<input type='hidden' id='userGuid' name='userGuid' value='<?php echo $userGuid ?>'>
 				<input type='hidden' id='guid' name='guid' value=''>
 			</form>
 				
@@ -836,4 +870,4 @@ require('loadUser.php');
 	</select>
 <br><br>
 </span>
-</div>
\ No newline at end of file
+</div>
