@@ -65,14 +65,16 @@ $(document).ready(function() {
 	// delete selected user //
 	$("#btn_delete").click(function() {
 		//console.log ('del')
+		var timestamp = Math.floor(Date.now() / 1000); 
 		var selected = $('#users tr.selected').attr('id');
+		console.log (selected)
 		var deleteUser = $('#users tr.selected').find('td:first').text();
 		if (typeof selected != "undefined" && selected.length > 3)
 		var n = noty({
         type: 'warning', layout: 'center', text: 'Delete User: <b>' + deleteUser + '</b> ?', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1, 
 		buttons     : [
             {addClass: 'btn btn-primary', text: 'OK', onClick: function ($noty) {
-				$.ajax({ url : 'userActions.php?mode=deleteUser&userName=' + encodeURIComponent(deleteUser) });
+				$.ajax({ url : 'userActions.php?mode=deleteUser&userGuid=' + encodeURIComponent(selected) + '&userName=' + encodeURIComponent(deleteUser) + '&timestamp=' + timestamp });
 					oTable.fnDeleteRow( oTable.$('#' + selected)[0] );
                     $noty.close(); 
 				}
@@ -98,7 +100,7 @@ $(document).ready(function() {
 		
         $('#element_to_pop_up').bPopup({
 			escClose: false, modalClose: false,
-            loadUrl: 'userForm.php?userMode=editUser&userName=' + userName,
+            loadUrl: 'userForm.php?userMode=editUser&userName=' + userName + '&userGuid=' + guid,
 			loadCallback: function(){ 	    
 				originalFormData = $('#new_user').serialize();
 				
@@ -112,6 +114,9 @@ $(document).ready(function() {
 				navigateoutlooklicense = $('#navigateoutlooklicense').val();
 				operatorconsolelicense = $('#operatorconsolelicense').val();
 				
+				selectediniitalmodule = $('#initialphonemodule').val();
+				selectedinitialdevice = $('#initialphone').val()
+				
 				$("#speedDialFrm").tableDnD({
 					onDrop: grouping,
 					scrollAmount: '100',
@@ -216,7 +221,33 @@ $(document).ready(function() {
 	
 	// save updates //
 	$("body").on('click', '#save', function() {
+		$('#msg_wrap').text('')
 		
+		if ( $('#callselect').is(':checked') ) {
+			var saveTele = $('#telephonenumber').val();
+			$.ajax({ type: "GET",   
+				url: "userActions.php?mode=callselect&telephonenumber=" + encodeURIComponent(saveTele),   
+				async: true,
+				success : function(data) {
+					if (data > '0') {
+						var n = noty({ type: 'error', layout: 'center', text: '<br/>Call Select can not be enabled when the user has a Vision Agent Licence<br/>Please contact your system administrator.<br/><br/><i>click to close</i>', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 });
+						$('#msg_wrap').text('Vision Agent licences can only be disabled by the administrator')
+						return false;
+					} else {
+						saveuser()
+					}
+				}	
+			})
+		} else {
+			saveuser()
+		}
+		
+		
+	})
+	
+	function saveuser() {
+		
+	var timestamp = Math.floor(Date.now() / 1000); 
 	var saveUserType = $('#usertype :selected').val();
 	var saveUser = $('#cn').val();
 	var saveTele = $('#telephonenumber').val();
@@ -253,9 +284,12 @@ $(document).ready(function() {
             {addClass: 'btn btn-primary', text: 'OK', onClick: function ($noty) {
 				//console.log ('save')
 				var userMode = $('#userMode').attr('value');
+				data = $('#new_user').serializeArray()
+				data.push({name: 'timestamp', value : timestamp}); 
+				
 				$.ajax({
 					type: "POST", cache: false,
-					data: $('#new_user').serializeArray(),
+					data: data,
 					url: "userActions.php?mode=saveUser", 	
 				success: function(data) {
 					console.log(data)
@@ -271,7 +305,8 @@ $(document).ready(function() {
 					type: "POST", cache: false,
 					data: {
 						speedDials: speedDials, 
-						speedGroupHeaders: speedGroupHeaders
+						speedGroupHeaders: speedGroupHeaders,
+						timestamp: timestamp
 					},
 					url: "userActions.php?mode=speedDials&userName=" + encodeURIComponent(name), 	
 					success: function(data) {
@@ -292,7 +327,7 @@ $(document).ready(function() {
 			}
             ]
         });
-	});
+	}
 	
 	
 	// SpeedDials //
@@ -337,7 +372,7 @@ $(document).ready(function() {
 		});
 		
 		if (id.length != 13) 
-			speedDials.push('del,' + id + ',0,0');
+			speedDials.push('del,' + id + ',' + telenum + ',0');
 		$(this).closest('tr').remove();
 		console.log ('del' + speedDials)
     });
@@ -515,7 +550,7 @@ $(document).ready(function() {
 				});
 				
 				if (headerGuid.length != 13)
-					speedGroupHeaders.push('del,' + headerGuid + ',' + HeaderId + ',0');
+					speedGroupHeaders.push('del,' + headerGuid + ',' + headerName + ',0');
 				
 				$('[data-speeddial=G\\:'+ HeaderId + ']').each(function() {
 					var id = $(this).closest('tr').attr('id')
@@ -591,6 +626,22 @@ $(document).ready(function() {
 		});
 	});
 	
+	// DECT Line
+	$('body').on('keyup', '#dectline', function(){
+		dectline =  $(this).val()
+		if ( !$.isNumeric(dectline) )  {
+				$('#msg').html('Only Numeric Values Supported'); 
+				$('#msg_wrap, #dectline').addClass('error');
+				$("#save").prop("disabled",true);
+			 } else {
+				$('#msg').html(''); 
+				$('#msg_wrap, #dectline').removeClass('error');
+				$("#save").prop("disabled",false);
+			 }
+	})
+	
+	
+	
 	// Extension check //
 	$('body').on('keyup', '#new_user input[name=telephonenumber], #new_user input[name=hometelephonenumber], #new_user input[name=mobiletelephonenumber]', function() {
 		fieldId = this.id;
@@ -738,16 +789,65 @@ $(document).ready(function() {
 		}
 	});
 	
+	$("body").on('change', '#disabled', function() {
+		if (!this.checked && $('#callselect').is(':checked')) {
+			console.log ("uncheck ?")
+			var n = noty({
+			type: 'warning', layout: 'center', text: 'Call Select is currently enabled.<br> Do you wish to disable this mode ?', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1, 
+				buttons     : [
+					{addClass: 'btn btn-primary', text: 'OK', onClick: function ($noty) {
+					$('#callselect').attr('checked', false);
+					$noty.close(); 
+					}
+				},
+				{addClass: 'btn btn-danger', text: 'Cancel', onClick: function ($noty) {
+					$noty.close(); }
+				}
+				]
+			});	
+		}
+	});
+	
+	
+	// call select check
+		$("body").on('change', '#callselect', function() {
+		var licenceCheck = $(this).attr('id')
+		var telephonenumber = $('#telephonenumber').val()
+		
+		if (document.getElementById(licenceCheck).checked) {
+			$.ajax({ type: "GET",   
+			url: "userActions.php?mode=callselect&telephonenumber=" + encodeURIComponent(telephonenumber),   
+			async: true,
+			success : function(data) {
+				if (data > '0') {
+					var n = noty({ type: 'error', layout: 'center', text: '<br/>Call Select can not be enabled when the user has a Vision Agent Licence<br/>Please contact your system administrator.<br/><br/><i>click to close</i>', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 });
+					$('#' + licenceCheck).prop('checked', false);
+				}
+			}	
+			});
+		}
+	});
+	// call select check
+	
 	// check licensing
 	$("body").on('change', '#messageboxlicense, #ipcslicense, #navigatesoftphonelicense, #navigatesfblicense, #siplicense, #totalcontrollicense', function() {
 		var licenceCheck = $(this).attr('id')
 		
+		
+		if (licenceCheck == 'messageboxlicense') {
+			if (this.checked && !$('#voicemailenabled').is(':checked')) {
+				var n = noty({ type: 'warning', layout: 'center', text: '<br/>Voicemail Box Not Enabled.<br/><br/><i>click to close</i>', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 });
+				$('#msg_wrap').text('Warning. Voicemail Box Not Enabled')
+			} else {
+				$('#msg_wrap').text('')
+			}
+		}
+						
 		if ( window[licenceCheck] > 0 ) {
 			console.log (' licence was already set ');
 			return false;
 		}
-		
-		
+				
 		var licenceArray = {'messageboxlicense': 'MessageBox', 'ipcslicense': 'iPCS', 'navigatesoftphonelicense': 'Navigate SoftPhone', 'navigatesfblicense' : 'Navigate Skype for Business Licence', 'siplicense': 'SIP Phone', 'totalcontrollicense': 'Web Portal'};
 		if (document.getElementById(licenceCheck).checked) {
 			$.ajax({ type: "GET",   
@@ -762,12 +862,45 @@ $(document).ready(function() {
 			}	
 			});
 		}
+		
 	});
 	
 	$("body").on('change', '#usertype', function() {
 		var usertype = $('#usertype :selected').text();
 		var usertypevalue = $('#usertype').val();
 		
+			// if virtual user clear module and device, set options disabled
+		if ( usertypevalue == 1 ) {
+			
+			$('#initialphonemodule').val('clear');
+			$("#initialphonemodule > option").each(function() {
+				if (this.value != 'clear') $(this).attr('disabled', true);
+			});
+			$('#initialphone').val('');
+			$("#initialphone > option").each(function() {
+				$(this).attr('disabled', true);
+			});
+			
+		} else {
+			// if not virtual reset module and device, set options enabled
+			$('#initialphonemodule, #initialphone').attr('disabled', false);
+			
+				if (selectediniitalmodule != 'clear') {
+					$('#initialphonemodule').val(selectediniitalmodule)
+					$('#initialphone').val(selectedinitialdevice)
+				}
+				
+				$("#initialphonemodule > option").each(function() {
+					$(this).attr('disabled', false);
+				});
+				
+				$("#initialphone > option").each(function() {
+					$(this).attr('disabled', false);
+				});
+			
+		}
+		
+		
 		if ( usertypevalue == usertypelicense ) {
 			console.log (' licence was already set ');
 			return false;
@@ -947,18 +1080,29 @@ $(document).ready(function() {
     });
 	
 	$("body").on('change', '#SelectGroup', function(e){
-			moveRowAfter = this.value		
-			console.log ('moveRowAfter = ' + moveRowAfter)	
-
-			$('#' + moveRowAfter).after(row)
-			grouping(0,row)
-			
-			$('#message').hide()
-			setTimeout(
-			function() {
-				$(row).removeAttr('style');
-			}, 1000);
-		})	
+		moveRowAfter = this.value		
+		console.log ('moveRowAfter = ' + moveRowAfter)	
+    
+		$('#' + moveRowAfter).after(row)
+		grouping(0,row)
+		
+		$('#message').hide()
+		setTimeout(
+		function() {
+			$(row).removeAttr('style');
+		}, 1000);
+	})	
+	
+	// check if vmlicence is applied if vm is enabled
+	$("body").on('change', '#voicemailenabled', function() {
+		if (this.checked && !$('#messageboxlicense').is(':checked')) {
+			var n = noty({ type: 'warning', layout: 'center', text: '<br/>Voicemail is being enabled, but no voicemail box licence is applied.<br/><br/><i>click to close</i>', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 });
+			$('#msg_wrap').text('Warning. No Voicemail Box Licence Applied')
+		} else {
+			$('#msg_wrap').text('')
+		}
+	})
+	
 });
 
 	function pad (str, max) {
@@ -1064,4 +1208,4 @@ $(document).ready(function() {
 		
 		console.log (speedDials)
 	}
-	
\ No newline at end of file
+	
