@@ -2,6 +2,7 @@
 // v1.6 08 July 2015 - Added POTS Module to Initial Phone Select
 
 session_start();
+$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL; // saveUser, speedDials, deleteUser, moduleList
 
 $ds = ldap_connect("127.0.0.1",4000);
 	if ( ! $ds) {
@@ -108,6 +109,7 @@ if ($unassigned == '1') {
   	$ipcslicence = (isset($_REQUEST["ipcslicence"]) && ($_REQUEST["ipcslicence"])=='on') ? '1' : '0';        
   	$navigatesoftphonelicence = (isset($_REQUEST["navigatesoftphonelicence"]) && ($_REQUEST["navigatesoftphonelicence"])=='on') ? '1' : '0';        
   	$navigateoutlooklicence = (isset($_REQUEST["navigateoutlooklicence"]) && strlen($_REQUEST["navigateoutlooklicence"])>=1) ? trim($_REQUEST["navigateoutlooklicence"]) : NULL;        
+  	$allowmultiplephones = (isset($_REQUEST["allowmultiplephones"]) && ($_REQUEST["allowmultiplephones"])=='on') ? '1' : '0';       
   
 	$caps1 = (isset($_REQUEST["caps1"]) && strlen($_REQUEST["caps1"])>1) ? trim($_REQUEST["caps1"]) : NULL;
   	$caps1value = (isset($_REQUEST["caps1value"]) && strlen($_REQUEST["caps1value"])>=1) ? trim($_REQUEST["caps1value"]) : NULL;
@@ -125,7 +127,8 @@ if ($unassigned == '1') {
 					 'spare2telephonenumber'=>$spare2phone, 'voicemailenabled'=>$voicemail, 'voicemailaccesscode'=>$voicemailaccesscode,
 					 'ocslicense'=>$ocslicence, 'messageboxlicense'=>$messageboxlicence, 'totalcontrollicense'=>$visionmobilitylicence,
 					 'operatorconsolelicense'=>$opsconsolelicence, 'agentlicense'=>$visionagentlicence, 'ipcslicense'=>$ipcslicence, 
-					 'navigatesoftphonelicense'=>$navigatesoftphonelicence, 'navigateoutlooklicense'=>$navigateoutlooklicence
+					 'navigatesoftphonelicense'=>$navigatesoftphonelicence, 'navigateoutlooklicense'=>$navigateoutlooklicence,
+					 'allowmultiplephones'=>$allowmultiplephones
 					 );
 					 
 	$result = ldap_add($ds,"cn=$username,cn=users",$newuser); 
@@ -235,6 +238,7 @@ if ($unassigned == '1') {
   	$ipcslicence = (isset($_REQUEST["ipcslicence"]) && ($_REQUEST["ipcslicence"])=='on') ? '1' : '0';        
   	$navigatesoftphonelicence = (isset($_REQUEST["navigatesoftphonelicence"]) && ($_REQUEST["navigatesoftphonelicence"])=='on') ? '1' : '0';        
   	$navigateoutlooklicence = (isset($_REQUEST["navigateoutlooklicence"]) && strlen($_REQUEST["navigateoutlooklicence"])>=1) ? trim($_REQUEST["navigateoutlooklicence"]) : NULL;        
+  	$allowmultiplephones = (isset($_REQUEST["allowmultiplephones"]) && ($_REQUEST["allowmultiplephones"])=='on') ? '1' : '0';       
   
 	$groups = (isset($_REQUEST["groups"]) && count($_REQUEST["groups"])>=1) ? $_REQUEST["groups"] : NULL;
 	
@@ -245,7 +249,8 @@ if ($unassigned == '1') {
 					 'spare2telephonenumber'=>$spare2phone, 'voicemailenabled'=>$voicemail, 'voicemailaccesscode'=>$voicemailaccesscode,
 					 'ocslicense'=>$ocslicence, 'messageboxlicense'=>$messageboxlicence, 'totalcontrollicense'=>$visionmobilitylicence,
 					 'operatorconsolelicense'=>$opsconsolelicence, 'agentlicense'=>$visionagentlicence, 'ipcslicense'=>$ipcslicence, 
-					 'navigatesoftphonelicense'=>$navigatesoftphonelicence, 'navigateoutlooklicense'=>$navigateoutlooklicence
+					 'navigatesoftphonelicense'=>$navigatesoftphonelicence, 'navigateoutlooklicense'=>$navigateoutlooklicence,
+					 'allowmultiplephones'=>$allowmultiplephones
 					 );
 
 	if ($user_cn != $username) {
@@ -308,4 +313,12 @@ if ($unassigned == '1') {
 	echo $result;
 }
 
+if ($mode === 'callselect') {
+	$telephonenumber = (isset($_REQUEST['telephonenumber']) && strlen($_REQUEST['telephonenumber']) >= 1) ? $_REQUEST['telephonenumber'] : NULL;
+	$sr = ldap_list($ds,"cn=Users","(&(objectclass=*)(telephonenumber=$telephonenumber))",array('telephonenumber','agentlicense'));
+		$info = ldap_get_entries($ds, $sr);
+		echo $info[0]['agentlicense'][0];
+		exit;
+}
+
 ?>
\ No newline at end of file
