@@ -1,12 +1,9 @@
 <?php
 session_start();
-// PJC 05-SEP-2019 - 097 - Move IP Phones
-// PJC 16-JUL-2019 - 096 - Update System Licences page
-// PJC 25-APR-2019 - 095 - Update STUN Page
-// PJC 18-DEC-2018 - 094 - SIPPhones Page
+// PJC 24-JUL-2020 - 096 iPCS
+// PJC 13-JUL-2020 - Update SIP Wizard to SIP / Team Wizard, redirect to Admin Portal
 // PJC 13-DEC-2018 - Show PCS/SSL, WebPatch & WebUprade on VMAP	  	
 // PJC 10-OCT-2018 - Hide DiskSpace, WebPatch, WebUpgrade,patch & upgrade vmap
-// PJC 28-JUN-2018 - 093 WallPaper 
 // PJC 29-JUN-2018 - Added 092 inittab
 // PJC 24-JAN-2017 - Added 091 Notifications
 // PJC 30-DEC-2016 - Added 090 TCPDUMP
@@ -284,7 +281,6 @@ check("CMD","</div>
 		  check("012","<a href='grouped_departments.php' class='tooltip' title='Put Groups Of Departments OutofHours And Play Selected Wav File'><b>Group Departments</b> - Enable OutofHours Messages</a>", $ma);
 		  check("083","<a href='portmap.php' class='tooltip' title='View Analogue Port Allocation'><b>PortMap</b> - View Analogue Port Allocation</a>", $ma);
 		  check("013","<a href='/manager/movephones.php' class='tooltip' title='Move Phones/PCSs From Module To Module'><b>Move Phones/PCS</b> - Between Modules. Fix POTS</a>", $ma);
-		  check("097","<a href='/manager/moveipphone.php' class='tooltip' title='Move IP Phones From Module To Module'><b>Move IP Phones</b> - Between Modules</a>", $ma);
 		  check("014","<a href='/manager/movehome.php' class='tooltip' title='Move Users Or Departments Voicemail Home'><b>Move Voicemail Home</b> - Users Or Departments</a>", $ma);
 		  
 		if ((isset($ma_acl) && strlen($ma_acl)>='1') || $manager_user=='Manager') {		  
@@ -299,7 +295,6 @@ check("CMD","</div>
 		  check("016","<a href='speeddials.php' class='tooltip' title='Manage Speed Dial Entries. Bulk Add, Remove, Import, Export And Update'><b>Speed Dials</b> - Add, Remove, Import, Export And Update</a>", $ma);
 		  check("017","<a href='licenceallocation.php' class='tooltip' title='View And Edit Licence Allocation For Trunks & Voicemail Ports'><b>Trunk And Voicemail Port Licences</b> - View & Edit</a>", $ma);
 		  check("018","<a href='trunks.php' class='tooltip' title='Bulk Remove Outgoing Callbar From Trunks'><b>Trunks</b> - Bulk Remove Outgoing Callbar</a>", $ma);
-		  check("096","<a href='licences.php' class='tooltip' title='Update System & Supplier Names and Apply Associated Licences'><b>System Licences</b> - Update System and Supplier Names and Licences</a>", $ma);
 		  check("019","<a href='unassigned.php' class='tooltip' title='View And Selectively Delete Unassigned Phones and Modules'><b>Unassigned</b> - View & Delete Unassigned Phones And Modules</a>", $ma);
 		  check("020","<a href='/manager/vlan.cgi' class='tooltip' title='Virtual LAN (VLAN) Config'><b>VLAN</b> - Virtual Lan (VLAN) Config</a>", $ma);
 		  check("021","<a href='websetnet.php' class='tooltip' title='Web Based Setnet Script'><b>WebSetnet</b> - Web Based Setnet Script</a>", $ma); ?>
@@ -370,9 +365,8 @@ check("CMD","</div>
 
 	<div class='sub'><strong class='strong'>Statistics</strong>
 	<?php 
-		if (! file_exists("/SpliceCom/install/assets/vmap")) {
-			check("046","<a href='log/diskspace.php' class='tooltip' title='View Current Disk Space And Clear Temporary Session Files'><b>Disk Space</b> - View Current Disk Space And Clear Temporary Session Files</a>", $ma);
-		}
+		$diskspacetitle = file_exists('/SpliceCom/install/assets/vmap') ? 'View Recordings Disk Space' : 'View Current Disk Space And Clear Temporary Session Files';
+		  check("046","<a href='log/diskspace.php' class='tooltip' title='$diskspacetitle'><b>Disk Space</b> - $diskspacetitle</a>", $ma);
 		  check("047","<a href='/manager/sysstat.php' class='tooltip' title='View System Statistics'><b>System Statistics</b> - View Details</a>", $ma);
 		  check("048","<a href='/manager/uptime.php' class='tooltip' title='Admin Module Uptime For This Callserver And System'><b>Uptime</b> - View System Uptime</a>", $ma); ?>
 	</div>		  
@@ -425,6 +419,7 @@ check("CMD","</div>
 		  check("092","<a href='inittab.php' class='tooltip' title='Configure CS5100 inittab'><B>inittab</b> - Configure CS5100 inittab</a>", $ma);
 	}
 		  check("065","<a href='/manager/ipaddresses.php' class='tooltip' title='Lists Ip Addresses Against Associated Name And Mac Address'><B>IP Addresses</b> - View IP Addresses and Associated Names and MAC Addresses</a>", $ma);
+		  check("096","<a href='/manager/assist/ipcs.php' class='tooltip' title='Clear iPCS iOS Push Registrations'><b>iPCS</b> - Clear iPCS iOS Push Registrations</a>", $ma);
 	 	  check("066","<a href='/manager/snmp.php' class='tooltip' title='Demonstration SNMP Page'><b>SNMP</b> - Simple Network Management Protocol Demonstration Page</a>", $ma);
 	 	  check("067","<a href='/manager/sorted.php' class='tooltip' title='Sorts By Name, Extension & Initial Phone And Searches For Duplicate Entries. Also Lists By Physical Phone'><b>Sorted</b> - Sorted Lists Of Users, Phones and Extensions</a>", $ma);
 	 	  check("068","<a href='/manager/users.php' class='tooltip' title='Checks That User Locations Are Consistent Across All Active Call Servers'><b>User Locations</b> - Check User Locations</a>", $ma);
@@ -440,7 +435,7 @@ check("CMD","</div>
 	<?php check("070","<a href='duplicate.php' class='tooltip' title='Duplicate Users, Dialplans, Lcrplans, Departments And Groups'><b>Duplicate</b> - Various System Settings</a>", $ma);
 	 	  check("071","<a href='pcs5xx.php' class='tooltip' title='Upload Logo And Ringtunes For The PCS5XX & PCS5X1 IP Phones. Site File Creation'><b>PCS5xx Logos</b> - Create PCS5xx & PCS5x1 Site Files</a>", $ma);
 	 	  check("072","<a href='/manager/screensaver.php' class='tooltip' title='Quick PCSXXX Screensaver Configuration'><b>PCS5xx Screen Saver</b> - Quick PCSxxx Configuration</a>", $ma);
-	 	  check("073","<a href='sipwizard.php' class='tooltip' title='Simply Create SIP Modules, Trunks, Lcrplan And Dialplan Entries'><b>SIP Trunks</b> - Guided Wizard</a>", $ma);
+	 	  check("073","<a href='../admin/sipwizard' class='tooltip' title='Create SIP / Teams Modules, Trunks, Lcrplan And Dialplan Entries'><b>SIP / Teams Trunks</b> - Guided Wizard</a>", $ma);
 	 	  check("074","<a href='administrator.php' class='tooltip' title='Create System Administrators'><b>System Administrators</b> - Create and Configure</a>", $ma);
 		  
 		  if (strpos($productversion, 'SV') !== false) {
