@@ -1,4 +1,5 @@
 <?php
+// 05-06-2020 PJC v1.01 Unset $ent
 // PJC v1.00
 
 include "tzone.php"; // include timezone
@@ -19,14 +20,14 @@ if (isset($_REQUEST['backup']) && $_REQUEST['backup']==="on") {
 	ldap_modify($ds,"cn=Commands", $ent);
 	ldap_modify($ds,"cn=Commands", $ent); $ent='';
 }
+
 $phones = (isset($_REQUEST['phones']) && count($_REQUEST['phones']) >0 ) ? $_REQUEST['phones'] : NULL;
 $stun = (isset($_REQUEST['stun']) && strlen($_REQUEST['stun']) >0 ) ? $_REQUEST['stun'] : NULL;
 $stunport = (isset($_REQUEST['stunport']) && strlen($_REQUEST['stunport']) >0 ) ? $_REQUEST['stunport'] : NULL;
 $stunmode = (isset($_REQUEST['stunmode']) && strlen($_REQUEST['stunmode']) >0 ) ? $_REQUEST['stunmode'] : NULL;
 
-
 if ($phones) {
-
+unset($ent);
 	foreach ($phones as $k => $guid) {
 		$dn = "cn=1,guid=$guid";
 		$ent["stunaddr"][0] = $stun;    
@@ -36,10 +37,6 @@ if ($phones) {
 		}
 		ldap_modify($ds, $dn, $ent); unset ($ent);
 	}
-	
 }
 	
-
-
-
 ?>
\ No newline at end of file
