@@ -168,7 +168,7 @@ show("Web backup completed");
 show("<b>Done</b><br/>");
 
 show("Changing to /SpliceCom/Mailbox<br/>Backing up /SpliceCom/Mailbox");
-exec('cd /SpliceCom/Mailbox; nice -10 tar --exclude=Archive --exclude=aadropbox --exclude=aatmp -cvf /SpliceCom/Web/download/voicemail.tar0 *');
+exec('cd /SpliceCom/; nice -10 tar --exclude=Archive --exclude=aadropbox --exclude=aatmp -cvhf /SpliceCom/Web/download/voicemail.tar0 Mailbox');
 show("Voicemail backup completed");
 show("<b>Done</b><br/>");
 
@@ -260,7 +260,7 @@ stop("<b>Done</b>...<br/><br/>No Backup file Created. Check The Items Exist On T
 if (isset($_REQUEST['action']) && $_REQUEST['action'] == '6') {
 $backup = $sysname."-BackupVoicemails-".date('d.m.y-His').".tar";
 show("Changing to /SpliceCom/Mailbox<br/>Backing up voicemails<br/>");
-exec("cd /SpliceCom/Mailbox; nice -10 tar --exclude=Archive --exclude=aadropbox --exclude=aatmp -cvf /SpliceCom/Web/download/$backup *");
+exec("cd /SpliceCom/; nice -10 tar --exclude=Archive --exclude=aadropbox --exclude=aatmp -cvhf /SpliceCom/Web/download/$backup Mailbox");
 show("Moving files and compressing<br/>");
 if (file_exists("/SpliceCom/Web/download/$backup")) {
 stop("<b>Done</b>...<br/><br/><a href='download.php?download=/SpliceCom/Web/download/$backup'><img src='images/down.png' alt='Download Backup' title='Download Backup' width='50' height='50'><br/>Download</a>");
