@@ -1,5 +1,6 @@
 <?php
 session_start();
+// PJC 07 July 2020 Updated wording to SoftPBX
 // PJC13SEP2018 - Updated ldappassword
 // PJC12AUG2018 - Increased timeout, runtime and refresh to allow larger configs.
 // PJC17FEB2015 - Layout
@@ -241,8 +242,8 @@ if (!isset($_SESSION['selected'])) {
          if ($info[$n]['moduletype'][0]==10) $_SESSION['modules']['type'][$n2]="4140";
          if ($info[$n]['moduletype'][0]==11) $_SESSION['modules']['type'][$n2]="5100";
          if ($info[$n]['moduletype'][0]==12) $_SESSION['modules']['type'][$n2]="5108";
-         if ($info[$n]['moduletype'][0]==17) $_SESSION['modules']['type'][$n2]="S8000 Linux";
-         if ($info[$n]['moduletype'][0]==18) $_SESSION['modules']['type'][$n2]="S8000 Apple";
+         if ($info[$n]['moduletype'][0]==17) $_SESSION['modules']['type'][$n2]="SoftPBX Linux";
+         if ($info[$n]['moduletype'][0]==18) $_SESSION['modules']['type'][$n2]="SoftPBX Apple";
 // Added by CNH to cope with 5500 NSG 19 April 2013
          if ($info[$n]['moduletype'][0]==19) $_SESSION['modules']['type'][$n2]="5500 (NSG)";
    	   $_SESSION['modules']['ipaddress'][$n2] = $info[$n]['ipaddress'][0];
@@ -294,7 +295,7 @@ if (!isset($_SESSION['selected'])) {
       	<th width='100px'>PublicIP&nbsp;<a href='#' class='tooltip' title='\"Public IP address\" - e.g. 80.79.78.76'><img src='assist/images/tooltip.gif'></a></th>
       	<th width='100px'>ConnectIP&nbsp;<a href='#' class='tooltip' title='\"Connecting using IP address\" - The IP address the call server you are running this web page on will use as the destination address for the particular Call Server.<br/> May be it&apos;s public IP address or it&apos;s real one.'><img src='assist/images/tooltip.gif'></a></th>
       	<th width='120px'>ModuleName&nbsp;<a href='#' class='tooltip' title='\"Module Name\" - As seen by Manager'><img src='assist/images/tooltip.gif'></a></th>
-      	<th width='120px'>ModuleType&nbsp;<a href='#' class='tooltip' title='\"Module Type\" - e.g. 4100, 4140, 5100, 5108, S8000'><img src='assist/images/tooltip.gif'></a></th>
+      	<th width='120px'>ModuleType&nbsp;<a href='#' class='tooltip' title='\"Module Type\" - e.g. 4100, 4140, 5100, 5108, SoftPBX'><img src='assist/images/tooltip.gif'></a></th>
       	<th width='100px'>Ver&nbsp;<a href='#' class='tooltip' title='\"Module Firmware Version\" - e.g. 3.2(1625)'><img src='assist/images/tooltip.gif'></a></th>
       	<th width='100px'>LastSeen&nbsp;<a href='#' class='tooltip' title='\"Last Seen\" - Number of days since database update from this call server.<br/>Typically 0, 2 or greater requires explaining.'><img src='assist/images/tooltip.gif'></a></th>
       	<th>State&nbsp;<a href='#' class='tooltip' title='\"Current State\" - Shows number of users as seen by this module and includes time taken.<br/>Error is shown if unable to communicate with module.'><img src='assist/images/tooltip.gif'></a></th>
