@@ -1,5 +1,6 @@
 <?php
 
+// PJC 20-07-2020 - Include SV10000 Managed User count in total when creating config.
 // PJC 14-08-2019
 // PJC 27-06-2016
 // Update for NSG Licence
@@ -148,6 +149,8 @@ if ($licence_select) {
 	$SVType = str_replace('-','',$licence[1]);
 	$voicemailPortCapacity = (strpos($SVType, 'SV1000') !== false) ? ${$SVType}['VoicemailPort'] : '0';
 	$ESPSession = (strpos($SVType, 'SV1000') !== false) ? ${$SVType}['ESPSession'] : '0';
+	$ManagedUserCount = (strpos($SVType, 'SV1000') !== false) ? ${$SVType}['ManagedUser'] : '0';
+	error_log ("ManagerUsers = $ManagedUserCount");
 }
 
 //// Default Config ////
@@ -239,13 +242,14 @@ if ($default_config && strlen($default_config) >0) {
 	// create users
 
 	//get ManagedUserLicence Count
-	$ManagedUserCount = '0';
+	//$ManagedUserCount = '0';
 	$sr = ldap_list($ds,"cn=system","(&(objectclass=license)(license=ManagedUser))",array('qty'));
 	$info = ldap_get_entries($ds,$sr);
     for ($n=0; $n<$info['count']; $n++) {
 		$ManagedUserCount = $ManagedUserCount+$info[$n]['qty'][0];
 	}
 
+	error_log ("ManagedUserCount = $ManagedUserCount");
 	$users = '10';
 	if (isset($ManagedUserCount) && $ManagedUserCount > 0) $users = $ManagedUserCount;
 	$users = ($users <= 1000) ? $users : '1000';
