@@ -231,7 +231,8 @@
 						$('#wizard').smartWizard('showMessage','No SV Licence Retrieved');
 					}
 					if (data[2] >=1) { 
-					   $("#userCount").text(data[2]);
+						svusercount = data[2]
+						$("#userCount").text(svusercount);
 					}
 				}
 			},
@@ -273,14 +274,25 @@
 			var isStepValid = true;
 			
 		// validate step 3
-		if(step == 3){
+		if(step == 3) {
+			
 			if(validateStep3() == false ){
 			isStepValid = false; 
 			//$('#wizard').smartWizard('showMessage','Please correct the errors in step'+step+ ' and click next.');
 			$('#wizard').smartWizard('setError',{stepnum:step,iserror:true});         
-		}else{
+		} else {
 			$('#wizard').smartWizard('hideMessage');
 			$('#wizard').smartWizard('setError',{stepnum:step,iserror:false});
+			
+			// SV Managed Users licences
+			if ( $('#licence_select').val() !== null ) {
+				SVManagerUsers = {'SV1000001' : 0, 'SV1000SC' : 0, 'SV1000MAPS' : 5, 'SV1000VMAP' : 0, 'SV1000MAP' : 0, 'SV1000NSG' : 0, 'SV1000OFF01' : 0, 'SV1000020' : 20};
+
+				svlicence = $('#licence_select').val().split(',')[1].replace('-',''); // get selected licence, get SV1000 & remove -
+				svcount = SVManagerUsers[svlicence];
+				updatedcount = parseInt(svcount) + parseInt(svusercount)
+				$('#userCount').text(updatedcount)
+				}
 			}
 		}
       
